@@ -19,8 +19,12 @@ tar_git_status_targets <- function(
   reporter = targets::tar_config_get("reporter_outdated"),
   envir = parent.frame(),
   callr_function = callr::r,
-  callr_arguments = targets::callr_args_default(callr_function, reporter)
+  callr_arguments = NULL
 ) {
+  callr_arguments <- callr_arguments %|||% callr_args_default(
+    callr_function = callr_function,
+    reporter = reporter
+  )
   outdated <- targets::tar_outdated(
     reporter = reporter,
     envir = envir,
